CacheMetadata class

Metadata for a single cached video.

Constructors

CacheMetadata({required int downloadedBytes, int? totalBytes, required bool isComplete, required DateTime lastUpdated, bool isHls = false})
CacheMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

downloadedBytes int
final
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
final
isHls bool
final
lastUpdated DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBytes int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited