HlsCacheManager class

Manages HLS/M3U8 video caching. Downloads segments progressively and generates local playlists.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cancel(String url) → void
Cancel HLS download.
cancelAll() → void
Cancel all HLS downloads.
clearCache(String url) Future<void>
Clear HLS cache for a URL.
getPlayablePath(String hlsUrl, {int prefetchSegments = 3, int? targetBandwidth, Map<String, String>? headers}) Future<HlsCacheResult>
Get a playable path for an HLS URL. Returns a local playlist path that can be played. Downloads segments progressively in background.