HlsCacheResult class
Result of getting playable HLS path.
Constructors
- HlsCacheResult({required String playlistPath, required bool isFullyCached, int? totalSegments, int? cachedSegments})
Properties
- cachedSegments → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFullyCached → bool
-
final
- playlistPath → String
-
final
- progress → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalSegments → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited