HlsMasterPlaylist class

Master playlist containing variant streams.

Inheritance

Constructors

HlsMasterPlaylist({required String url, required List<HlsVariant> variants})

Properties

bestVariant HlsVariant?
Get best variant (highest bandwidth).
no setter
hashCode int
The hash code for this object.
no setterinherited
isMaster bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
finalinherited
variants List<HlsVariant>
final

Methods

getVariantByBandwidth(int targetBandwidth) HlsVariant?
Get variant by target bandwidth.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited