HlsMediaPlaylist class

Media playlist containing segments.

Inheritance

Constructors

HlsMediaPlaylist({required String url, required List<HlsSegment> segments, required double targetDuration, required int mediaSequence, required bool isLive})

Properties

hashCode int
The hash code for this object.
no setterinherited
isLive bool
final
isMaster bool
no setteroverride
mediaSequence int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<HlsSegment>
final
targetDuration double
final
totalDuration double
Total duration in seconds.
no setter
url String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited