HlsParser class

HLS/M3U8 playlist parser. Parses master playlists (variant streams) and media playlists (segments).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isHlsUrl(String url) bool
Check if URL is HLS.
parse(String content, String playlistUrl) HlsPlaylist
Parse an M3U8 playlist content. Returns HlsMasterPlaylist if master, HlsMediaPlaylist if media.