DownloadProgress class

Progress update from downloader.

Constructors

DownloadProgress({required String url, required int downloadedBytes, int? totalBytes, required bool isComplete})

Properties

downloadedBytes int
final
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
final
progress double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBytes int?
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited