PrefetchConfig class

Configuration for adaptive prefetching based on network conditions

Constructors

PrefetchConfig({int prefetchAhead = 3, int prefetchBehind = 1, int keepRange = 5, int maxConcurrent = 3})
const
PrefetchConfig.forNetwork(NetworkType type)
Adaptive config based on network type
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
keepRange int
final
maxConcurrent int
final
prefetchAhead int
final
prefetchBehind int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited