DownloadResult class
Result of downloading until minimum bytes threshold.
Constructors
-
DownloadResult({required int downloadedBytes, required bool isComplete, StreamSubscription<
DownloadProgress> ? subscription})
Properties
- downloadedBytes → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComplete → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscription
→ StreamSubscription<
DownloadProgress> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited